pub enum LabelFormat {
PDF,
ZPL,
}Expand description
LabelFormat : The file format in which the shipping label will be created. The file format in which the shipping label will be created.
Variants
PDF
ZPL